import os
import json

# from ferris_cli.ferris_cli import ApplicationConfigurator

APP_NAME = os.environ['APP_NAME']

# app_config = ApplicationConfigurator().get(APP_NAME)
# env = ApplicationConfigurator().get("ferris.env")

TOPIC_NAME = os.environ['TOPIC_NAME']

MODULE_NAME = os.environ['MODULE_NAME']
CLASS_NAME = os.environ['CLASS_NAME']

BATCH_NUMBER = int(os.environ['BATCH_NUMBER'])
BATCH_FRAME = int(os.environ['BATCH_FRAME'])

KAFKA_NODES = json.loads(os.environ['KAFKA_NODES'])
LOG_TO_KAFKA_LEVEL = os.environ['LOG_TO_KAFKA_LEVEL']




import logging

import faust
# from ferris_cli.ferris_cli import FerrisKafkaLoggingHandler
# from logstash_formatter import LogstashFormatterV1
from ferris_sx import settings as s

app = faust.App(s.APP_NAME,
                broker=[f'kafka://{url}' for url in s.KAFKA_NODES],
                topic_disable_leader=True,
                autodiscover=True,
                origin='ferris_sx')

app.logger = logging.getLogger(s.APP_NAME)
logger = logging.getLogger(s.APP_NAME)
# kh = FerrisKafkaLoggingHandler()
# kh.setLevel(s.LOG_TO_KAFKA_LEVEL)
# formatter = LogstashFormatterV1()
# kh.setFormatter(formatter)
# logger.addHandler(kh)



import os

from setuptools import setup

PROJECT_ROOT, _ = os.path.split(__file__)

NAME = 'ferris-sx'
EMAILS = 'murat@ferrislabs.net'
AUTHORS = 'Murat Dacić'
VERSION = '0.1.0'

URL = 'https://github.com/Ferris-Labs/ferris-sx/tree/main'
LICENSE = 'Apache2.0'


SHORT_DESCRIPTION = 'Library for creating Stream Processors on top of Kafka and running them inside Ferris platform'

try:
    import pypandoc
    DESCRIPTION = pypandoc.convert(os.path.join(PROJECT_ROOT, 'README.md'),
                                   'rst')
except (IOError, ImportError):
    DESCRIPTION = SHORT_DESCRIPTION

INSTALL_REQUIRES = open(os.path.join(PROJECT_ROOT, 'requirements.txt')). \
        read().splitlines()


setup(
    name=NAME,
    version=VERSION,
    author=AUTHORS,
    author_email=EMAILS,
    packages=[
        'ferris_sx',
        ],
    install_requires=INSTALL_REQUIRES,
    url=URL,
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    description=SHORT_DESCRIPTION,
    long_description=DESCRIPTION,
    license=LICENSE,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Topic :: System :: Logging',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



from .core import app
from . import settings as s

topic = app.topic(s.TOPIC_NAME)


@app.agent(topic)
async def listener(messages):
    if s.BATCH_NUMBER > 1:
        print("batch")
        async for list_msg in messages.take(s.BATCH_NUMBER, within=s.BATCH_FRAME):
            app.process(list_msg)
    else:
        print("single")
        async for m in messages:
            app.process(m)
